@@ -116,7 +116,7 @@ void MoleculePrivate::ExportTo3D (Molecule *mol)
 	write (f, cml, strlen (cml));
 	close (f);
 	g_free (cml);
-	char *command_line = g_strconcat ("gchem3d-"GCU_API_VER" ", tmpname, NULL);
+	char *command_line = g_strconcat ("gchem3d-" GCU_API_VER " ", tmpname, NULL);
 	g_free (tmpname);
 	g_spawn_command_line_async (command_line, NULL);
 	g_free (command_line);
@@ -674,7 +674,7 @@ void Molecule::OpenCalc ()
 	list<gcu::Atom*>::iterator ia, enda = m_Atoms.end ();
 	ostringstream ofs;
 	int nH;
-	ofs << "gchemcalc-"API_VERSION" ";
+	ofs << "gchemcalc-" API_VERSION " ";
 	for (ia = m_Atoms.begin(); ia != enda; ia++) {
 		ofs << (*ia)->GetSymbol();
 		nH = reinterpret_cast <Atom *> (*ia)->GetAttachedHydrogens ();
@@ -740,7 +740,11 @@ static void BuildConnectivity (gcu::Atom *atom, set < gcu::Atom * > &ConnectedAt
 
 void Molecule::OnLoaded ()
 {
-	// First check if we have only one molecule or split, this might happen with
+	// First update fragments;
+	std::list < Fragment * >::iterator f, fend = m_Fragments.end ();
+	for (f = m_Fragments.begin (); f != fend; f++)
+		(*f)->Update ();
+	// Then check if we have only one molecule or split, this might happen with
 	// cml (root node being molecule) or malformed files.
 	if (m_Atoms.size () + m_Fragments.size () > 1) {
 		/* FIXME: what should be done with fragments? */
@@ -777,7 +781,8 @@ void Molecule::OnLoaded ()
 			// remove new_mol children from there
 			std::list < gcu::Atom * >::iterator a, aend = new_mol->m_Atoms.end ();
 			std::list < gcu::Bond * >::iterator b, bend = new_mol->m_Bonds.end ();
-			std::list < Fragment * >::iterator f, fend = new_mol->m_Fragments.end ();
+			fend = new_mol->m_Fragments.end ();
+			// update fragments if needed
 			for (a = new_mol->m_Atoms.begin (); a != aend; a++)
 				m_Atoms.remove (*a);
 			for (b = new_mol->m_Bonds.begin (); b != bend; b++)
