@@ -162,10 +162,10 @@ static GtkActionEntry entries[] = {
 	  {"BlockColors", NULL, N_("Block"), NULL,
 		  N_("Use colors to display the blocks elements belong to"),
                   G_CALLBACK (on_block_colors) },
-    {"ChartMenu", NULL, N_("Element charts "), NULL, NULL, NULL },
-      { "en-Pauling", NULL, N_("Electronegativty "), NULL,
+    {"ChartMenu", NULL, N_("Element charts"), NULL, NULL, NULL },
+      { "en-Pauling", NULL, N_("Electronegativity"), NULL,
 		  N_("Create an electronegativity chart"), G_CALLBACK (on_chart) },
-      { "ae", NULL, N_("Electon affinity"), NULL,
+      { "ae", NULL, N_("Electron affinity"), NULL,
 		  N_("Create an electronic affinity chart"), G_CALLBACK (on_chart) },
       { "ei-1", NULL, N_("First ionization energy"), NULL,
 		  N_("Create an first ionization energy chart"), G_CALLBACK (on_chart) },
@@ -181,8 +181,8 @@ static GtkActionEntry entries[] = {
 		  N_("Create an atomic metallic radius chart"), G_CALLBACK (on_chart) },
       { "mp", NULL, N_("Melting temperature"), NULL,
 		  N_("Create an melting temperature chart"), G_CALLBACK (on_chart) },
-      { "bp", NULL, N_("Ebullition temperature"), NULL,
-		  N_("Create an ebullition temperature chart"), G_CALLBACK (on_chart) },
+      { "bp", NULL, N_("Boiling temperature"), NULL,
+		  N_("Create an boiling temperature chart"), G_CALLBACK (on_chart) },
 	  { "CustomChart", NULL, N_("Custom"), NULL,
 		  N_("Create a custom chart"), G_CALLBACK (on_new_chart) },
   { "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
